# Experimental code

This directory contains experimental code (I don't upload it to github anymore).
This code is unstable, and should not be used in projects.

Also the old experiments (which failed, but for some reason it is important to keep them) are stored here as well.
